@@ -2,7 +2,7 @@
 Toontown Rewritten API Wrapper
 ==============================
 
-A basic wrapper for the Toontown Rewritten API
+A basic wrapper for the Toontown Rewritten/Corporate Clash API
 
 :copyright: (c) 2022-present jaczerob
 :license: MIT, see LICENSE for more details.
@@ -12,14 +12,12 @@ __title__ = 'toontown'
 __author__ = 'jaczerob'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2022-present jaczerob'
-__version__ = '1.1.3'
+__version__ = '2.0.1'
 
 __path__ = __import__('pkgutil').extend_path(__path__, __name__)
 
 import logging
 
-from .client import *
 from .exceptions import *
-from .httpclient import *
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
